@@ -13,6 +13,8 @@ from .settings import *
 def _create_targets(clean_data: pd.DataFrame,
                     target_settings: TargetSettings
                     ):
+    target_eng = []
+
     if type(target_settings).__name__ == TsfreshTargetSettings.__name__:
         target_eng = f_tsfresh.calculate_forwards(ohlc=clean_data,
                                                   win_lens=[target_settings.win_len],
@@ -35,6 +37,9 @@ def _create_targets(clean_data: pd.DataFrame,
             feature_name=target_settings.target_col_feature_subtype,
             columns=target_eng.columns, is_fwd=True)
 
+    if len(target_eng) == 0:
+        return target_eng
+
     target_eng = target_eng[[target_col]]
 
     target_eng = f_cleaner.clip_quantile(target_eng)
@@ -165,6 +170,10 @@ class FeatureCreatorManager:
 
 
         features = f_common.combine_features(features_list=[features_lags, features])
+
+        if len(features) == 0:
+            return features, clean_data
+
         features = f_common.add_ohlc(data=features, ohlc=clean_data)
 
         return features, clean_data
